@@ -6,6 +6,10 @@
 
 ##### Adjust these always
 
+# Uncomment if you have the fast ".opt" compilers
+#CAMLC = ocamlc.opt
+#CAMLOPT = ocamlopt.opt
+
 # Where to put the lablgl script
 BINDIR = /usr/local/bin
 
@@ -20,40 +24,40 @@ TKINCLUDES = -I/usr/local/include
 # Tcl/Tk libs (for broken RTLD_GLOBAL: e.g. FreeBSD 4.0)
 #TKLIBS = -L/usr/local/lib -ltk83 -ltcl83
 
-# Where to find OpenGL/Mesa headers and libraries
+# Where to find OpenGL/Mesa/Glut headers and libraries
 GLINCLUDES =
 GLLIBS = -lGL -lGLU
+GLUTLIBS = -lglut
 # The following libraries may be required (try to add them one at a time)
-# GLLIBS = -lGL -lGLU -lXmu -lXext -lpthread
+#GLLIBS = -lGL -lGLU -lXmu -lXext -lXi -lcipher -lpthread
 
-# How to index a library
-RANLIB = ranlib
-#RANLIB = :
+# How to index a library after installing (ranlib required on MacOSX)
+RANLIB = :
+#RANLIB = ranlib
+
+##### Uncomment these for windows
+#TKLIBS = tk83.lib tcl83.lib gdi32.lib user32.lib
+#GLLIBS = opengl32.lib glu32.lib 
+#TOOLCHAIN = msvc
+#XA = .lib
+#XB = .bat
+#XE = .exe
+#XO = .obj
+#XS = .dll
 
 ##### Adjust these if non standard
 
 # The Objective Caml library directory
-LIBDIR = `ocamlc -where`
+#LIBDIR = `ocamlc -where`
 
-# Where is LablTk (standard)
-LABLTKDIR = $(LIBDIR)/labltk
+# Where to put dlls (if dynamic loading available)
+#DLLDIR = `ocamlc -where`/stublibs
 
 # Where to put LablGL (standard)
-INSTALLDIR = $(LIBDIR)/lablGL
+#INSTALLDIR = $(LIBDIR)/lablGL
 
 # Where is Togl (default)
-TOGLDIR = Togl
+#TOGLDIR = Togl
 
 # C Compiler options
-COPTS = -c -O
-
-###### No need to change these
-
-# Where to find tcl.h, tk.h, OpenGL/Mesa headers, etc:
-INCLUDES = $(TKINCLUDES) $(GLINCLUDES) $(XINCLUDES)
-
-# Libraries to link with:
-LIBS = $(TKLIBS) $(GLLIBS) $(XLIBS)
-
-# Leave this empty
-LIBDIRS =
+#COPTS = -c -O
